summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kaccountsview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kaccountsview.h')
-rw-r--r--kmymoney2/views/kaccountsview.h37
1 files changed, 19 insertions, 18 deletions
diff --git a/kmymoney2/views/kaccountsview.h b/kmymoney2/views/kaccountsview.h
index ed30ac5..33a787c 100644
--- a/kmymoney2/views/kaccountsview.h
+++ b/kmymoney2/views/kaccountsview.h
@@ -49,12 +49,12 @@ public:
/**
* Constructor to be used to construct an account icon object.
*
* @param parent pointer to the KIconView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KIconView entry is constructed
*/
- KMyMoneyAccountIconItem(QIconView *parent, const MyMoneyAccount& account);
+ KMyMoneyAccountIconItem(TQIconView *tqparent, const MyMoneyAccount& account);
~KMyMoneyAccountIconItem();
/**
@@ -87,10 +87,11 @@ private:
class KAccountsView : public KAccountsViewDecl
{
Q_OBJECT
+ TQ_OBJECT
private:
public:
- KAccountsView(QWidget *parent=0, const char *name=0);
+ KAccountsView(TQWidget *tqparent=0, const char *name=0);
virtual ~KAccountsView();
public slots:
@@ -103,8 +104,8 @@ public slots:
void show(void);
/**
- * Override the base class behaviour to restore the layout. Do not
- * do this in show() because show() itself may change the layout
+ * Override the base class behaviour to restore the tqlayout. Do not
+ * do this in show() because show() itself may change the tqlayout
* in undesired ways.
*/
void polish(void);
@@ -117,7 +118,7 @@ public slots:
*/
void slotUpdateIconPos(unsigned int action);
- void slotReconcileAccount(const MyMoneyAccount& acc, const QDate& reconciliationDate, const MyMoneyMoney& endingBalance);
+ void slotReconcileAccount(const MyMoneyAccount& acc, const TQDate& reconciliationDate, const MyMoneyMoney& endingBalance);
protected:
typedef enum {
@@ -136,7 +137,7 @@ protected:
void loadListView(void);
void loadIconView(void);
- bool loadSubAccounts(KMyMoneyAccountTreeItem* parent, const QStringList& accountList);
+ bool loadSubAccounts(KMyMoneyAccountTreeItem* tqparent, const TQStringList& accountList);
/**
* This method returns a pointer to the currently selected
@@ -144,15 +145,15 @@ protected:
*/
KMyMoneyAccountIconItem* selectedIcon(void) const;
- QPoint point(const QString& str) const;
- QString point(const QPoint& val) const;
+ TQPoint point(const TQString& str) const;
+ TQString point(const TQPoint& val) const;
protected slots:
void slotUpdateNetWorth(void);
- void slotTabChanged(QWidget*);
- void slotSelectIcon(QIconViewItem* item);
- void slotOpenContext(QIconViewItem* item);
- void slotOpenObject(QIconViewItem* item);
+ void slotTabChanged(TQWidget*);
+ void slotSelectIcon(TQIconViewItem* item);
+ void slotOpenContext(TQIconViewItem* item);
+ void slotOpenObject(TQIconViewItem* item);
void slotExpandCollapse(void);
signals:
@@ -181,17 +182,17 @@ signals:
/**
* This signal is emitted, when the user selected to reparent the
* account @p acc to be a subordinate account of @p parent.
*
* @param acc const reference to account to be reparented
* @param parent const reference to new parent account
*/
- void reparent(const MyMoneyAccount& acc, const MyMoneyAccount& parent);
+ void reparent(const MyMoneyAccount& acc, const MyMoneyAccount& tqparent);
private:
MyMoneyAccount m_reconciliationAccount;
- QMap<QString, MyMoneySecurity> m_securityMap;
- QMap<QString, unsigned long> m_transactionCountMap;
+ TQMap<TQString, MyMoneySecurity> m_securityMap;
+ TQMap<TQString, unsigned long> m_transactionCountMap;
KMyMoneyAccountTreeItem* m_assetItem;
KMyMoneyAccountTreeItem* m_liabilityItem;
@@ -49,12 +49,12 @@ public:
* Constructor to be used to construct an account icon object.
*
- * @param parent pointer to the KIconView object this entry should be
+ * @param tqparent pointer to the KIconView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
@@ -181,17 +182,17 @@ signals:
/**
* This signal is emitted, when the user selected to reparent the
- * account @p acc to be a subordinate account of @p parent.
+ * account @p acc to be a subordinate account of @p tqparent.
*
* @param acc const reference to account to be reparented
@@ -181,17 +182,17 @@ signals:
*
* @param acc const reference to account to be reparented
- * @param parent const reference to new parent account
+ * @param tqparent const reference to new tqparent account
*/